@@ -91,10 +91,13 @@ class Gitbook(Repository):
 
   def table_of_contents(self) -> str:
     logging.debug("generate_table_of_contents(%s)", self)
-    assert self.summary
+    assert self.summary and self.toc
 
     lines = ["# Table of Contents"]
     for markdown in self.summary.extract_summary():
+      logging.info("sumamry from markdown: %s", markdown)
+      if markdown.path == self.toc.path:
+        continue
       lines += [f"\n{'#' * (markdown.nest_count + 1)} {markdown.path.relative_to(self.path).name}\n"]
       lines += [markdown.table_of_contents(self.url_path)]
 
